@@ -71,7 +71,7 @@ from .reaction_parser import make_reaction_parser
 logger = logging.getLogger(__name__)
 
 
-def find_most_abundance_ms(
+def find_most_abundant_ms(
     cpd: Compound, p_h: Q_, p_mg: Q_, ionic_strength: Q_, temperature: Q_
 ) -> CompoundMicrospecies:
     """Find the most abundant microspecies based on transformed energies."""
@@ -103,7 +103,7 @@ def predict_protons_and_charge(
             n_h += coeff
             z += coeff
         else:
-            ms = find_most_abundance_ms(
+            ms = find_most_abundant_ms(
                 cpd, p_h, p_mg, ionic_strength, temperature
             )
             n_h += coeff * ms.number_protons
@@ -424,9 +424,13 @@ class ComponentContribution(object):
         Returns
         -------
         mu : float
-            the mean of the standard Gibbs energy of formation
-        sigma : array
-            the uncertainty vector
+            the mean of the standard formation Gibbs energy estimate
+        sigma_fin : array
+            a vector representing the square root of the covariance matrix
+            (uncertainty)
+        sigma_inf : array
+            a vector representing the infinite-uncertainty eigenvalues of the
+            covariance matrix
 
         """
         return self.predictor.get_compound_prediction(compound)
@@ -771,7 +775,7 @@ class ComponentContribution(object):
             the ionic strength outside
         p_mg_outer : Quantity (optional)
             the pMg in the outside compartment
-        Tolerance : Float (optional)
+        tolerance : Float (optional)
             tolerance for identifying inbalance between inner and outer
             reactions (default = 0)
 
@@ -804,9 +808,7 @@ class ComponentContribution(object):
         assert n_mg_inner == 0, "most abundant inner species have Mg2+"
         assert n_mg_outer == 0, "most abundant outer species have Mg2+"
 
-        if (abs(n_h_inner + n_h_outer) > tolerance) or (
-            abs(z_inner + z_outer) > tolerance
-        ):
+        if abs(n_h_inner - z_inner + n_h_outer - z_outer) > tolerance:
             raise ValueError(
                 "inner and outer half-reactions don't balance each other: "
                 f"n_h(inner) = {n_h_inner}, n_h(outer) = {n_h_outer}, "
@@ -814,6 +816,15 @@ class ComponentContribution(object):
                 f"tolerance = {tolerance}"
             )
 
+        # when (n_h_inner - z_inner + n_h_outer - z_outer) is about 0,
+        # this means that either (n_h_inner = z_inner) and (n_h_outer =
+        # z_outer) which means everything is balanced, or that the imbalance
+        # is the same for the protons and the charge. In the latter case,
+        # things can easily be solved by adding more protons to the inner
+        # reaction until things are balanced. Doing this will not change the
+        # results of multicompartmental_standard_dg_prime() so we continue as
+        # if things are balanced.
+
         transported_protons = n_h_outer
         transported_charge = z_outer
 
